summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndoni Morales Alastruey <amorales@flumotion.com>2010-11-19 17:22:06 +0100
committerAlessandro Decina <alessandro.d@gmail.com>2010-11-19 18:10:47 +0100
commit2611b12970d2c2254ecc3f0a6f02a09ffa82a16a (patch)
tree1754a6bbb29357091b800193512501b7f87d4847
parent7c43c2fa06bc685245c4b69afc16a46f56d394ce (diff)
mpegtsparse: don't calculate the CRC for TOT tables. Fixes #635281.
TOT tables, with table_id=0x73, don't have a CRC, so don't calcute it
-rw-r--r--gst/mpegdemux/mpegtsparse.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gst/mpegdemux/mpegtsparse.c b/gst/mpegdemux/mpegtsparse.c
index a50e90fb6..18c76160b 100644
--- a/gst/mpegdemux/mpegtsparse.c
+++ b/gst/mpegdemux/mpegtsparse.c
@@ -1135,8 +1135,8 @@ mpegts_parse_handle_psi (MpegTSParse * parse, MpegTSPacketizerSection * section)
gboolean res = TRUE;
GstStructure *structure = NULL;
- /* table ids 0x70 - 0x72 do not have a crc */
- if (G_LIKELY (section->table_id < 0x70 || section->table_id > 0x72)) {
+ /* table ids 0x70 - 0x73 do not have a crc */
+ if (G_LIKELY (section->table_id < 0x70 || section->table_id > 0x73)) {
if (G_UNLIKELY (mpegts_parse_calc_crc32 (GST_BUFFER_DATA (section->buffer),
GST_BUFFER_SIZE (section->buffer)) != 0)) {
GST_WARNING_OBJECT (parse, "bad crc in psi pid 0x%x", section->pid);